@@ -20,6 +20,8 @@
 
 /* global variables */
 VALUE cgsl_block, cgsl_block_int;
+VALUE cgsl_block_uchar;
+VALUE cgsl_block_complex;
 VALUE cgsl_vector, cgsl_vector_view;
 VALUE cgsl_vector_view_ro;
 VALUE cgsl_vector_col_view_ro;
@@ -33,6 +35,7 @@ VALUE cgsl_matrix_complex_view;
 VALUE cgsl_vector_complex_view_ro;
 VALUE cgsl_matrix_complex_view_ro;
 VALUE cgsl_permutation;
+VALUE cgsl_index;
 VALUE cgsl_vector_col, cgsl_vector_col_view;
 VALUE cgsl_vector_complex_col, cgsl_vector_complex_col_view;
 
@@ -44,14 +47,26 @@ VALUE cgsl_matrix_int, cgsl_matrix_int_view;
 double* get_vector_ptr(VALUE ary, size_t *stride, size_t *n)
 {
   gsl_vector *v = NULL;
+  gsl_vector_complex *vc = NULL;
+  gsl_matrix *m;
 #ifdef HAVE_NARRAY_H
   VALUE ary2;
 #endif
-  if (rb_obj_is_kind_of(ary, cgsl_vector)) {
+  if (VECTOR_P(ary)) {
     Data_Get_Struct(ary, gsl_vector, v);
     *stride = v->stride;
     *n = v->size;
     return v->data;
+  } else if (VECTOR_COMPLEX_P(ary)) {
+    Data_Get_Struct(ary, gsl_vector_complex, vc);
+    *stride = vc->stride;
+    *n = vc->size*2;
+    return vc->data;
+  } else if (MATRIX_P(ary)) {
+    Data_Get_Struct(ary, gsl_matrix, m);
+    *stride = 1;
+    *n = m->size1*m->size2;
+    return m->data;
 #ifdef HAVE_NARRAY_H
   } else if (NA_IsNArray(ary)) {
     *n = NA_TOTAL(ary);
@@ -483,6 +498,34 @@ VALUE rb_gsl_range2ary(VALUE obj)
   return ary;
 }
 
+VALUE rb_gsl_range2vector(VALUE obj)
+{
+  int beg, en, i, step;
+  size_t n;
+  gsl_vector *v;
+  if (CLASS_OF(obj) != rb_cRange) 
+    rb_raise(rb_eTypeError, "wrong argument type %s (Range expected)",
+	     rb_class2name(CLASS_OF(obj)));
+  get_range_beg_en_n(obj, &beg, &en, &n, &step);
+  v = gsl_vector_alloc(n);
+  for (i = 0; i < n; i++) gsl_vector_set(v, i, (double) (beg+i));
+  return Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, v);
+}
+
+VALUE rb_gsl_range2vector_int(VALUE obj)
+{
+  int beg, en, i, step;
+  size_t n;
+  gsl_vector_int *v;
+  if (CLASS_OF(obj) != rb_cRange) 
+    rb_raise(rb_eTypeError, "wrong argument type %s (Range expected)",
+	     rb_class2name(CLASS_OF(obj)));
+  get_range_beg_en_n(obj, &beg, &en, &n, &step);
+  v = gsl_vector_int_alloc(n);
+  for (i = 0; i < n; i++) gsl_vector_int_set(v, i, beg+i);
+  return Data_Wrap_Struct(cgsl_vector_int, 0, gsl_vector_int_free, v);
+}
+
 gsl_vector_int_view* rb_gsl_vector_int_view_alloc(size_t n)
 {
   gsl_vector_int_view *v;
@@ -524,24 +567,26 @@ void rb_gsl_matrix_int_view_free(gsl_matrix_int_view * mv)
   free((gsl_matrix_int_view *) mv);
 }
 
-void Init_gsl_block_init(VALUE module);
-void Init_gsl_block_int_init(VALUE module);
 void Init_gsl_array(VALUE module)
 {
   cgsl_block = rb_define_class_under(module, "Block", 
-					 rb_cObject);
+					 cGSL_Object);
   cgsl_block_int = rb_define_class_under(cgsl_block, "Int", 
-					 rb_cObject);
+					 cGSL_Object);
+  cgsl_block_uchar = rb_define_class_under(cgsl_block, "Byte", 
+					   cGSL_Object);
+
+  cgsl_block_complex = rb_define_class_under(cgsl_block, "Complex", cgsl_block);
   cgsl_vector = rb_define_class_under(module, "Vector", 
-				      rb_cObject);
+				      cGSL_Object);
   cgsl_vector_col = rb_define_class_under(cgsl_vector, "Col", 
 					 cgsl_vector);
   cgsl_vector_complex = rb_define_class_under(cgsl_vector, "Complex", 
-					      rb_cObject);
+					      cGSL_Object);
   cgsl_vector_complex_col = rb_define_class_under(cgsl_vector_complex, "Col",
 					      cgsl_vector_complex);
-  cgsl_matrix = rb_define_class_under(module, "Matrix", rb_cObject);
-  cgsl_matrix_complex = rb_define_class_under(cgsl_matrix, "Complex", rb_cObject);
+  cgsl_matrix = rb_define_class_under(module, "Matrix", cGSL_Object);
+  cgsl_matrix_complex = rb_define_class_under(cgsl_matrix, "Complex", cGSL_Object);
 
   cgsl_vector_view = rb_define_class_under(cgsl_vector, "View", cgsl_vector);
   cgsl_vector_col_view = rb_define_class_under(cgsl_vector_col, "View", cgsl_vector_col);
@@ -551,17 +596,20 @@ void Init_gsl_array(VALUE module)
   cgsl_vector_complex_col_view = rb_define_class_under(cgsl_vector_complex_col, "View", 
 						   cgsl_vector_complex_col);
 
-  cgsl_vector_int = rb_define_class_under(cgsl_vector, "Int", rb_cObject);
-  cgsl_vector_int_col = rb_define_class_under(cgsl_vector_int, "Col", cgsl_vector_int);  cgsl_vector_int_view = rb_define_class_under(cgsl_vector_int, "View", cgsl_vector_int);
+  cgsl_vector_int = rb_define_class_under(cgsl_vector, "Int", cGSL_Object);
+  cgsl_vector_int_col = rb_define_class_under(cgsl_vector_int, "Col", cgsl_vector_int);  
+  cgsl_vector_int_view = rb_define_class_under(cgsl_vector_int, "View", cgsl_vector_int);
   cgsl_vector_int_col_view = rb_define_class_under(cgsl_vector_int_col, "View", cgsl_vector_int_col);
 
+
   /*****/
 
   cgsl_matrix_view = rb_define_class_under(cgsl_matrix, "View", 
 					   cgsl_matrix);
   cgsl_matrix_complex_view = rb_define_class_under(cgsl_matrix_complex, "View", 
 						   cgsl_matrix_complex);
-  cgsl_permutation = rb_define_class_under(module, "Permutation", rb_cObject);  
+  cgsl_permutation = rb_define_class_under(module, "Permutation", cGSL_Object);  
+  cgsl_index = rb_define_class_under(module, "Index", cgsl_permutation);
 
   cgsl_vector_view_ro = rb_define_class_under(cgsl_vector_view, "ReadOnly",
 					      cgsl_vector_view);
@@ -582,12 +630,13 @@ void Init_gsl_array(VALUE module)
 						      cgsl_matrix_complex_view);
 
   /*****/
-  cgsl_matrix_int = rb_define_class_under(cgsl_matrix, "Int", rb_cObject);
+  cgsl_matrix_int = rb_define_class_under(cgsl_matrix, "Int", cGSL_Object);
   cgsl_matrix_int_view = rb_define_class_under(cgsl_matrix_int, "View", cgsl_matrix_int);
 
   /*****/
   Init_gsl_block_init(module);
   Init_gsl_block_int_init(module);
+  Init_gsl_block_uchar_init(module);
   Init_gsl_vector(module);
   Init_gsl_vector_int(module);
 
