@@ -57,7 +57,7 @@ VALUE FUNCTION(rb_gsl_matrix,do_something)(VALUE obj, void (*f)(GSL_TYPE(gsl_mat
 
 static VALUE FUNCTION(create_matrix,from_range_shape)(VALUE range, VALUE nn1, VALUE nn2);
 static VALUE FUNCTION(create_matrix,from_ranges)(int argc, VALUE *argv);
-static VALUE FUNCTION(rb_gsl_matrix,new)(int argc, VALUE *argv, VALUE klass)
+static VALUE FUNCTION(rb_gsl_matrix,alloc)(int argc, VALUE *argv, VALUE klass)
 {
   GSL_TYPE(gsl_matrix) *m = NULL;
   size_t n1, n2;
@@ -141,7 +141,7 @@ static VALUE FUNCTION(rb_gsl_matrix,new)(int argc, VALUE *argv, VALUE klass)
 void get_range_beg_en_n(VALUE range, int *beg, int *en, size_t *n, int *step);
 void FUNCTION(set_ptr_data,by_range)(BASE *ptr, size_t n, VALUE range);
 
-static VALUE FUNCTION(create_matrix,from_ranges)(int argc, VALUE *argv)
+static GSL_TYPE(gsl_matrix)* FUNCTION(cr_matrix,from_ranges)(int argc, VALUE *argv)
 {
   GSL_TYPE(gsl_matrix) *m;
   size_t i, n;
@@ -155,16 +155,30 @@ static VALUE FUNCTION(create_matrix,from_ranges)(int argc, VALUE *argv)
 	       rb_class2name(CLASS_OF(argv[i])));
     FUNCTION(set_ptr_data,by_range)(m->data+i*n, n, argv[i]);
   }
+  return m;
+}
+
+static VALUE FUNCTION(create_matrix,from_ranges)(int argc, VALUE *argv)
+{
+  GSL_TYPE(gsl_matrix) *m;
+  m = FUNCTION(cr_matrix,from_ranges)(argc, argv);
   return Data_Wrap_Struct(GSL_TYPE(cgsl_matrix), 0, FUNCTION(gsl_matrix,free), m);
 }
 
-static VALUE FUNCTION(create_matrix,from_range_shape)(VALUE range, VALUE nn1, VALUE nn2)
+static GSL_TYPE(gsl_matrix)* FUNCTION(cr_matrix,from_range_shape)(VALUE range, VALUE nn1, VALUE nn2)
 {
   size_t n1, n2;
   GSL_TYPE(gsl_matrix) *m;
   n1 = FIX2INT(nn1);  n2 = FIX2INT(nn2);
   m = FUNCTION(gsl_matrix,alloc)(n1, n2);
   FUNCTION(set_ptr_data,by_range)(m->data, n1*n2, range);
+  return m;
+}
+
+static VALUE FUNCTION(create_matrix,from_range_shape)(VALUE range, VALUE nn1, VALUE nn2)
+{
+  GSL_TYPE(gsl_matrix) *m;
+  m = FUNCTION(cr_matrix,from_range_shape)(range, nn1, nn2);
   return Data_Wrap_Struct(GSL_TYPE(cgsl_matrix), 0, FUNCTION(gsl_matrix,free), m);
 }
 
@@ -1816,9 +1830,9 @@ static VALUE FUNCTION(rb_gsl_matrix,abs)(VALUE obj)
 
 void FUNCTION(Init_gsl_matrix,init)(VALUE module)
 {
-  rb_define_singleton_method(GSL_TYPE(cgsl_matrix), "new", FUNCTION(rb_gsl_matrix,new), -1);
-  rb_define_singleton_method(GSL_TYPE(cgsl_matrix), "[]", FUNCTION(rb_gsl_matrix,new), -1);
-  rb_define_singleton_method(GSL_TYPE(cgsl_matrix), "alloc", FUNCTION(rb_gsl_matrix,new), -1);
+  /*  rb_define_singleton_method(GSL_TYPE(cgsl_matrix), "new", FUNCTION(rb_gsl_matrix,alloc), -1);*/
+  rb_define_singleton_method(GSL_TYPE(cgsl_matrix), "[]", FUNCTION(rb_gsl_matrix,alloc), -1);
+  rb_define_singleton_method(GSL_TYPE(cgsl_matrix), "alloc", FUNCTION(rb_gsl_matrix,alloc), -1);
   rb_define_singleton_method(GSL_TYPE(cgsl_matrix), "calloc", FUNCTION(rb_gsl_matrix,calloc), 2);
   rb_define_singleton_method(GSL_TYPE(cgsl_matrix), "eye", FUNCTION(rb_gsl_matrix,eye), -1);
   rb_define_singleton_method(GSL_TYPE(cgsl_matrix), "diagonal", 
