@@ -45,7 +45,8 @@ static VALUE rb_gsl_monte_function_set_f(int argc, VALUE *argv, VALUE obj)
   Data_Get_Struct(obj, gsl_monte_function, F);
   if (F->params == NULL) {
     ary = rb_ary_new2(2);
-    (VALUE) F->params = ary;
+    /*    (VALUE) F->params = ary;*/
+    F->params = (void *) ary;
   } else {
     ary = (VALUE) F->params;
   }
@@ -93,7 +94,8 @@ static VALUE rb_gsl_monte_function_new(int argc, VALUE *argv, VALUE klass)
   VALUE obj;
   f = ALLOC(gsl_monte_function);
   f->f = &rb_gsl_monte_function_f;
-  (VALUE) f->params = rb_ary_new2(2);
+  /*  (VALUE) f->params = rb_ary_new2(2);*/
+  f->params = (void *) rb_ary_new2(2);
   rb_ary_store((VALUE) f->params, 1, Qnil);
   obj = Data_Wrap_Struct(klass, gsl_monte_function_mark, gsl_monte_function_free, f);
   rb_gsl_monte_function_set_f(argc, argv, obj);
@@ -667,10 +669,10 @@ void Init_gsl_monte(VALUE module)
   rb_define_const(mgsl_monte, "MISER", INT2FIX(GSL_MONTE_MISER_STATE));
   rb_define_const(mgsl_monte, "VEGAS", INT2FIX(GSL_MONTE_VEGAS_STATE));
 
-  cgsl_monte_function = rb_define_class_under(mgsl_monte, "Function", rb_cObject);
-  cgsl_monte_plain = rb_define_class_under(mgsl_monte, "Plain", rb_cObject);
-  cgsl_monte_miser = rb_define_class_under(mgsl_monte, "Miser", rb_cObject);
-  cgsl_monte_vegas = rb_define_class_under(mgsl_monte, "Vegas", rb_cObject);
+  cgsl_monte_function = rb_define_class_under(mgsl_monte, "Function", cGSL_Object);
+  cgsl_monte_plain = rb_define_class_under(mgsl_monte, "Plain", cGSL_Object);
+  cgsl_monte_miser = rb_define_class_under(mgsl_monte, "Miser", cGSL_Object);
+  cgsl_monte_vegas = rb_define_class_under(mgsl_monte, "Vegas", cGSL_Object);
 
   rb_define_singleton_method(cgsl_monte_function, "new", rb_gsl_monte_function_new, -1);
   rb_define_singleton_method(cgsl_monte_function, "alloc", rb_gsl_monte_function_new, -1);
