@@ -1598,6 +1598,74 @@ static VALUE rb_gsl_ran_erlang_pdf(VALUE obj, VALUE x, VALUE a, VALUE n)
 }
 */
 
+#ifdef GSL_1_8_LATER
+
+static VALUE rb_gsl_ran_gaussian_ziggurat(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_rng *r = NULL;	
+  gsl_vector *v;
+  size_t n, i;
+  double sigma = 1.0;
+  switch (TYPE(obj)) {
+  case T_MODULE: case T_CLASS: case T_OBJECT:
+    switch (argc) {
+    case 3:
+      n = NUM2INT(argv[2]);
+      sigma = NUM2DBL(argv[1]);
+      CHECK_RNG(argv[0]);
+      Data_Get_Struct(argv[0], gsl_rng, r);    
+      v = gsl_vector_alloc(n);
+      for (i = 0; i < n; i++) 
+	gsl_vector_set(v, i, gsl_ran_gaussian_ziggurat(r, sigma));
+      return Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, v);
+      break;
+    case 2:
+      sigma = NUM2DBL(argv[1]);
+      /* no break */
+    case 1:
+      CHECK_RNG(argv[0]);
+      Data_Get_Struct(argv[0], gsl_rng, r);    
+      return rb_float_new(gsl_ran_gaussian_ziggurat(r, sigma));
+      break;
+    default:
+      rb_raise(rb_eArgError, "too many arguments (%d for 1 or 2)", argc);
+      return Qnil;
+      break;
+    }
+    break;
+  default:
+    Data_Get_Struct(obj, gsl_rng, r);    
+    switch (argc) {
+    case 2:
+      n = NUM2INT(argv[1]);
+      sigma = NUM2DBL(argv[0]);
+      v = gsl_vector_alloc(n);
+      for (i = 0; i < n; i++) 
+	gsl_vector_set(v, i, gsl_ran_gaussian_ziggurat(r, sigma));
+      return Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, v);
+      break;
+    case 1:
+      sigma = NUM2DBL(argv[0]);
+      /* no break */
+    case 0:
+      return rb_float_new(gsl_ran_gaussian_ziggurat(r, sigma));
+      break;
+    default:
+      rb_raise(rb_eArgError, "too many arguments (%d for 0 or 1)", argc);
+      return Qnil;
+      break;
+    }
+    break;
+  }
+  return Qnil;
+}
+
+static VALUE rb_gsl_ran_gamma_mt(int argc, VALUE *argv, VALUE obj)
+{
+  return rb_gsl_ran_eval2(argc, argv, obj, gsl_ran_gamma_mt);
+}
+#endif
+
 void Init_gsl_ran(VALUE module)
 {
   VALUE mgsl_ran;
@@ -1778,7 +1846,7 @@ void Init_gsl_ran(VALUE module)
   /*****/
 
   cgsl_ran_discrete = rb_define_class_under(mgsl_ran, "Discrete", cGSL_Object);
-  rb_define_singleton_method(cgsl_ran_discrete, "new", rb_gsl_ran_discrete_new, 1);
+  rb_define_singleton_method(cgsl_ran_discrete, "alloc", rb_gsl_ran_discrete_new, 1);
   rb_define_singleton_method(cgsl_ran_discrete, "preproc", rb_gsl_ran_discrete_new, 1);
   rb_define_method(cgsl_rng, "discrete", rb_gsl_ran_discrete, 1);
   rb_define_module_function(mgsl_ran,  "discrete_pdf", rb_gsl_ran_discrete_pdf, 2);
@@ -1792,4 +1860,12 @@ void Init_gsl_ran(VALUE module)
   /*  rb_define_method(cgsl_rng, "erlang", rb_gsl_ran_erlang, 2);
   rb_define_method(module, "ran_erlang_pdf", rb_gsl_ran_erlang_pdf, 3);
   rb_define_method(mgsl_ran, "erlang_pdf", rb_gsl_ran_erlang_pdf, 3);*/
+
+#ifdef GSL_1_8_LATER
+  rb_define_module_function(mgsl_ran, "gaussian_ziggurat", rb_gsl_ran_gaussian_ziggurat, -1);
+  rb_define_method(cgsl_rng, "gaussian_ziggurat", rb_gsl_ran_gaussian_ziggurat, -1);
+  rb_define_module_function(mgsl_ran, "gamma_mt", rb_gsl_ran_gamma_mt, -1);
+  rb_define_method(cgsl_rng, "gamma_mt", rb_gsl_ran_gamma_mt, -1);
+#endif
+
 }
