@@ -308,12 +308,10 @@ static VALUE rb_gsl_vector_complex_set_all(int argc, VALUE *argv, VALUE obj)
 static VALUE rb_gsl_vector_complex_each(VALUE obj)
 {
   gsl_vector_complex *v = NULL;
-  size_t size;
   gsl_complex *zp = NULL, ztmp, *zp2 = &ztmp;
   size_t i;
   Data_Get_Struct(obj, gsl_vector_complex, v);
-  size = v->size;
-  for (i = 0; i < size; i++) {
+  for (i = 0; i < v->size; i++) {
     zp = GSL_COMPLEX_AT(v, i);
     ztmp = *zp;  /* create a temporal copy of *zp */
     rb_yield(Data_Wrap_Struct(cgsl_complex, 0, NULL, zp2));
@@ -321,14 +319,39 @@ static VALUE rb_gsl_vector_complex_each(VALUE obj)
   return obj;
 }
 
+static VALUE rb_gsl_vector_complex_reverse_each(VALUE obj)
+{
+  gsl_vector_complex *v = NULL;
+  gsl_complex *zp = NULL, ztmp, *zp2 = &ztmp;
+  size_t i;
+  Data_Get_Struct(obj, gsl_vector_complex, v);
+  for (i = v->size-1; i >= 0; i--) {
+    zp = GSL_COMPLEX_AT(v, i);
+    ztmp = *zp;  /* create a temporal copy of *zp */
+    rb_yield(Data_Wrap_Struct(cgsl_complex, 0, NULL, zp2));
+    if (i == 0) break;
+  }
+  return obj;
+}
+
 static VALUE rb_gsl_vector_complex_each_index(VALUE obj)
 {
   gsl_vector_complex *v = NULL;
-  size_t size;
   size_t i;
   Data_Get_Struct(obj, gsl_vector_complex, v);
-  size = v->size;
-  for (i = 0; i < size; i++) rb_yield(INT2FIX(i));
+  for (i = 0; i < v->size; i++) rb_yield(INT2FIX(i));
+  return obj;
+}
+
+static VALUE rb_gsl_vector_complex_reverse_each_index(VALUE obj)
+{
+  gsl_vector_complex *v = NULL;
+  size_t i;
+  Data_Get_Struct(obj, gsl_vector_complex, v);
+  for (i = v->size-1; i >= 0; i--) {
+    rb_yield(INT2FIX(i));
+    if (i == 0) break;
+  }
   return obj;
 }
 
@@ -1432,7 +1455,9 @@ void Init_gsl_vector_complex(VALUE module)
   rb_define_method(cgsl_vector_complex, "set_all", rb_gsl_vector_complex_set_all, -1);
 
   rb_define_method(cgsl_vector_complex, "each", rb_gsl_vector_complex_each, 0);
+  rb_define_method(cgsl_vector_complex, "reverse_each", rb_gsl_vector_complex_reverse_each, 0);
   rb_define_method(cgsl_vector_complex, "each_index", rb_gsl_vector_complex_each_index, 0);
+  rb_define_method(cgsl_vector_complex, "reverse_each_index", rb_gsl_vector_complex_reverse_each_index, 0);
   rb_define_method(cgsl_vector_complex, "collect", rb_gsl_vector_complex_collect, 0);
   rb_define_method(cgsl_vector_complex, "collect!", rb_gsl_vector_complex_collect_bang, 0);
 
