@@ -112,4 +112,10 @@ void Init_gsl_dirac(VALUE module);
 
 EXTERN VALUE cGSL_Object;
 
+void Init_tamu_anova(VALUE module);
+
+#ifdef HAVE_TAMU_ANOVA_TAMU_ANOVA_H
+#include "tamu_anova/tamu_anova.h"
+#endif
+
 #endif
