@@ -1,11 +1,11 @@
 #!/usr/bin/env ruby
-require("gsl")
+require("rbgsl")
 
 a = 1
-t = Vector.linspace(0, 2*M_PI, 100)
+t = GSL::Vector.linspace(0, 2*Math::PI, 100)
 cost = Sf::cos(t)
 sint = Sf::sin(t)
 x = a*cost
 y = a*sint*cost/(1 + sint*sint)
 
-graph(x, y, "-T X -C")
+GSL::graph(x, y, "-T X -C")
