@@ -4,9 +4,9 @@ require("gsl")
 N = 10000
 BINS = 100
 
-rng1 = Rng.new(2)
+rng1 = Rng.alloc(2)
 
-h = Histogram.new(BINS, [-5, 5])
+h = GSL::Histogram.alloc(BINS, [-5, 5])
 
 for i in 0...N do
   r1 = rng1.gaussian
