@@ -9,7 +9,7 @@ def ran_power_law(slope, range, rng)
   return pow(x2, 1.0/(1+slope));
 end
 
-h = Histogram.alloc(19, [1, 20])
+h = GSL::Histogram.alloc(19, [1, 20])
 rng = Rng.alloc
 for i in 0..5000
   x = ran_power_law(-3.2, 1000, rng)
@@ -17,7 +17,7 @@ for i in 0..5000
 end
 
 result = h.fit_power
-x = Vector.logspace2(1, 20, 19)
+x = GSL::Vector.logspace2(1, 20, 19)
 y = result[0]*pow(x, result[1])
 graph(h, [x, y], "-l x -l y -x 1 20 -y 1 10000 -C -g 3")
 
