@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
 require("gsl")
 
-h = Histogram.alloc(100, [-4, 4])
+h = GSL::Histogram.alloc(100, [-4, 4])
 
 rng = Rng.alloc
 for i in 0..10000 do
