@@ -2,7 +2,7 @@
 require("gsl")
 include Linalg
 
-m = Matrix::new([0.18, 0.60, 0.57, 0.96], [0.41, 0.24, 0.99, 0.58],
+m = Matrix::alloc([0.18, 0.60, 0.57, 0.96], [0.41, 0.24, 0.99, 0.58],
 		    [0.14, 0.30, 0.97, 0.66], [0.51, 0.13, 0.19, 0.85])
 m.print
 
@@ -46,11 +46,11 @@ p LU.solve(m, b)
 
 puts("")
 
-m2 = Matrix.new([1, 2, 3, 6, 5, 4, 7, 8, 1], 3, 3)
+m2 = Matrix.alloc([1, 2, 3, 6, 5, 4, 7, 8, 1], 3, 3)
 m2.print
 lu2, p2, sign = m2.LU_decomp
 
-m3 = Matrix.new([1, 2, 3, 4, 5, 6, 7, 8, 0], 3, 3)
+m3 = Matrix.alloc([1, 2, 3, 4, 5, 6, 7, 8, 0], 3, 3)
 m3.print
 lu, perm = m3.LU_decomp
 LU.invert(lu, perm).print
