@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
 require("gsl")
 
-a = Matrix.new([1, 2, 3, 4, 5, 6, 7, 8, 9], 3, 3)
+a = Matrix.alloc([1, 2, 3, 4, 5, 6, 7, 8, 9], 3, 3)
 p a
 
 b = a.get_row(0)
