@@ -2,7 +2,7 @@
 #
 # Solve Legendre's differential equation
 #   l = 2, m = 1
-require("gsl")
+require("rbgsl")
 dim = 2
 
 fleg = Proc.new { |x, y, f, params|
@@ -12,7 +12,7 @@ fleg = Proc.new { |x, y, f, params|
   f[1] = 2.0*x/(1-x*x)*y[1] - (l*(l + 1) - m*m/(1-x*x))/(1-x*x)*y[0]
 }
 
-solver = Odeiv::Solver.new(Odeiv::Step::RKF45, [1e-6, 0.0], fleg, dim)
+solver = GSL::Odeiv::Solver.alloc(GSL::Odeiv::Step::RKF45, [1e-6, 0.0], fleg, dim)
 
 # P21
 l = 2
@@ -27,7 +27,7 @@ h = hstart*1.0
 
 # Initial conditions, at x = 0
 # P21(0) = 0, P21'(0) = 3
-y = Vector.new(0.0, 3.0)
+y = GSL::Vector.alloc(0.0, 3.0)
 
 File.open("legode.dat", "w") do |f|
   while x < xend
@@ -40,7 +40,7 @@ end
 File.open("plm.dat", "w") do |f|
   x = 0.0
   while x < xend
-    plmx = Sf::legendre_Plm(l, m, x).abs
+    plmx = GSL::Sf::legendre_Plm(l, m, x).abs
     f.printf("%g %g\n", x, plmx)
     x += 0.01
   end
