@@ -10,12 +10,12 @@ M = 1000
 GSL::Rng.env_setup()
 T = Rng::DEFAULT
 seed = 2
-rng = GSL::Rng.new(T, seed)
+rng = GSL::Rng.alloc(T, seed)
 
 h = Array.new(3)
-h[0] = Histogram.new(61, -30, 30)
-h[1] = Histogram.new(61, -30, 30)
-h[2] = Histogram.new(61, -30, 30)
+h[0] = Histogram.alloc(61, -30, 30)
+h[1] = Histogram.alloc(61, -30, 30)
+h[2] = Histogram.alloc(61, -30, 30)
 
 i = 0
 for n in [6, 50, 100] do
