@@ -4,7 +4,7 @@ require("gsl")
 N = 1000
 GSL::Rng.env_setup()
 T = Rng::DEFAULT
-r = GSL::Rng.new(T)
+r = GSL::Rng.alloc(T)
 
 x = 0.0
 y = 0.0
