@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
 require("gsl")
 
-v = Vector.new([17.2, 18.1, 16.5, 18.3, 12.6])
+v = Vector.alloc([17.2, 18.1, 16.5, 18.3, 12.6])
 p Stats.mean(v)
 p Stats.variance(v)
 p Stats.sd(v)
