@@ -1,13 +1,13 @@
 #!/usr/bin/env ruby
 # Ruby/GSL implementation of GSL "interpolation/test.c"
-require("gsl")
+require("rbgsl")
 require("./gsl_test2.rb")
 include GSL::Test
 include Math
 
 def test_bsearch()
   status = 0
-  x_array = Vector.new(0.0, 1.0, 2.0, 3.0, 4.0)
+  x_array = GSL::Vector.alloc(0.0, 1.0, 2.0, 3.0, 4.0)
   index_result = Interp.bsearch(x_array, 1.5, 0, 4)
   s = (index_result != 1) ? 1 : 0
   status += 1
