@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 # Ruby/GSL implementation of GSL "roots/test.c"
-require("gsl")
+require("rbgsl")
 require("./gsl_test2.rb")
 include GSL::Test
 include Math
@@ -14,7 +14,7 @@ def WITHIN_TOL(a, b, epsrel, epsabs)
 end
 
 def test_f(type, desc, f, lower, upper, correct)
-  s = GSL::Root::FSolver.new(type)
+  s = GSL::Root::FSolver.alloc(type)
   s.set(f, lower, upper)
   iter = 0
   begin
@@ -41,14 +41,14 @@ def test_f(type, desc, f, lower, upper, correct)
 end
 
 def test_fdf(type, desc, fdf, root, correct)
-  s = Root::FdfSolver.new(type)
+  s = GSL::Root::FdfSolver.alloc(type)
   s.set(fdf, root)
   iter = 0
   begin
     iter += 1
     prev = s.root
     s.iterate
-    status = Root::test_delta(s.root, prev, EPSABS, EPSREL)
+    status = GSL::Root::test_delta(s.root, prev, EPSABS, EPSREL)
   end while status == GSL::CONTINUE and iter < MAX_ITERATIONS
   GSL::Test::test(status, "#{s.name} #{desc} (#{s.root} obs vs #{correct} expected)")
   if iter == MAX_ITERATIONS
@@ -59,10 +59,10 @@ def test_fdf(type, desc, fdf, root, correct)
   end    
 end
 
-func1 = Function.new { |x| pow(x, 20.0) - 1 }
+func1 = GSL::Function.alloc { |x| pow(x, 20.0) - 1 }
 func1_fdf = Proc.new { |x| 20.0*pow(x, 19.0) }
 
-fdf1 = Function_fdf.new(func1.f, func1_fdf)
+fdf1 = GSL::Function_fdf.alloc(func1.f, func1_fdf)
 
 fsolvers = ["bisection", "brent", "falsepos"]
 fsolvers.each do |type|
